@@ -15,6 +15,7 @@ private:
 public:
     QString name ();
     QString selfNumber ();
+    bool isValid ();
 
 public slots:
     void initiateCall (const QString &strDestination);
@@ -23,6 +24,9 @@ private slots:
     void onSkypeConnected (bool bSuccess, const QVariantList &params);
     void onCallInitiated (bool bSuccess, const QVariantList &params);
 
+private:
+    void attemptCreateSkypeClient ();
+
 private:
     SkypeClient *skypeClient;
     QString      strNumber;
