@@ -5,10 +5,35 @@
 TpCalloutInitiator::TpCalloutInitiator (Tp::AccountPtr act, QObject *parent)
 : CalloutInitiator(parent)
 , account (act)
+, strActCmName("undefined")
 , strSelfNumber("undefined")
 , bIsSpirit (false)
 {
+    QObject::connect (
+        account.data (), SIGNAL(connectionChanged(const Tp::ConnectionPtr &)),
+        this, SLOT(onConnectionChanged(const Tp::ConnectionPtr &)));
+
+    QObject::connect (
+        account.data(),
+        SIGNAL(connectionStatusChanged(Tp::ConnectionStatus,
+                                       Tp::ConnectionStatusReason)),
+        this, SLOT(onConnectionChanged(Tp::ConnectionStatus,
+                                       Tp::ConnectionStatusReason)));
+
     Tp::ConnectionPtr connection = account->connection();
+    onConnectionChanged (connection);
+}//TpCalloutInitiator::TpCalloutInitiator
+
+void
+TpCalloutInitiator::onConnectionChanged (Tp::ConnectionStatus, Tp::ConnectionStatusReason)
+{
+    Tp::ConnectionPtr connection = account->connection();
+    onConnectionChanged (connection);
+}
+
+void
+TpCalloutInitiator::onConnectionChanged (const Tp::ConnectionPtr &connection)
+{
     if (!connection.isNull ())
     {
         QObject::connect (connection->becomeReady (),
@@ -16,7 +41,7 @@ TpCalloutInitiator::TpCalloutInitiator (Tp::AccountPtr act, QObject *parent)
                           this,
                           SLOT (onConnectionReady (Tp::PendingOperation *)));
     }
-}//TpCalloutInitiator::TpCalloutInitiator
+}//TpCalloutInitiator::onConnectionChanged
 
 void
 TpCalloutInitiator::onConnectionReady (Tp::PendingOperation *op)
@@ -28,6 +53,10 @@ TpCalloutInitiator::onConnectionReady (Tp::PendingOperation *op)
             break;
         }
 
+        // Whenever the account changes state, we change state.
+        QObject::connect (account.data (), SIGNAL(stateChanged(bool)),
+                          this           , SIGNAL(changed()));
+
         Tp::ContactPtr contact = account->connection()->selfContact();
         if (!contact.isNull ())
         {
@@ -39,11 +68,13 @@ TpCalloutInitiator::onConnectionReady (Tp::PendingOperation *op)
         }
         qDebug ("Self Contact is null");
 
-        if (account->cmName () == "spirit") {
+        strActCmName = account->cmName ();
+        if (strActCmName == "spirit") {
+            strActCmName = "Skype";
             bIsSpirit = true;
         }
 
-        if (account->cmName () == "sofiasip")
+        if (strActCmName == "sofiasip")
         {
             strSelfNumber = account->parameters()["auth-user"].toString();
             if (!strSelfNumber.isEmpty ()) break;
@@ -51,6 +82,11 @@ TpCalloutInitiator::onConnectionReady (Tp::PendingOperation *op)
             if (!strSelfNumber.isEmpty ()) break;
         }
 
+        if (strActCmName == "ring") {
+            strSelfNumber = "This phone's MSISDN";
+            strActCmName = "Phone";
+        }
+
         msg = QString ("Yet to figure out how to get phone number from %1")
               .arg (account->cmName ());
         qDebug () << msg;
@@ -67,6 +103,7 @@ TpCalloutInitiator::onConnectionReady (Tp::PendingOperation *op)
         }
     } while (0); // End cleanup block (not a loop)
 
+    emit changed ();
     op->deleteLater ();
 }//TpCalloutInitiator::onConnectionReady
 
@@ -111,7 +148,7 @@ TpCalloutInitiator::onChannelReady (Tp::PendingOperation*op)
 QString
 TpCalloutInitiator::name ()
 {
-    return (account->cmName ());
+    return (strActCmName);
 }//TpCalloutInitiator::name
 
 QString
@@ -119,3 +156,10 @@ TpCalloutInitiator::selfNumber ()
 {
     return (strSelfNumber);
 }//TpCalloutInitiator::selfNumber
+
+bool
+TpCalloutInitiator::isValid ()
+{
+    return (!account.isNull () && !account->connection().isNull () &&
+            account->isEnabled () && account->isValid ());
+}//TpCalloutInitiator::isValid
