@@ -17,16 +17,21 @@ private:
 public:
     QString name ();
     QString selfNumber ();
+    bool isValid ();
 
 public slots:
     void initiateCall (const QString &strDestination);
 
 private slots:
+    void onConnectionChanged (const Tp::ConnectionPtr &connection);
+    void onConnectionChanged (Tp::ConnectionStatus, Tp::ConnectionStatusReason);
+
     void onChannelReady (Tp::PendingOperation *op);
     void onConnectionReady (Tp::PendingOperation *op);
 
 private:
     Tp::AccountPtr      account;
+    QString             strActCmName;
     QString             strSelfNumber;
 
     //! Is this the buggy spirit (skype) TP-CM?
